# Overview
Description

## Addressed issues
*  Issues addressed

## Showcase
A short / one-liner example to highlight the (new) feature
```
import splinepy

new, feature = splinepy.tataratat()
```

## Checklists
* [ ] Documentations are up-to-date.
* [ ] Added example(s)
* [ ] Added test(s)
